/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.datamodel
 * File:    SearchResultImpl.java
 *
 * Copyright (C) 2010-2011 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.datamodel;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import de.fhhannover.inform.iron.mapserver.datamodel.graph.MetadataContainer;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.meta.Metadata;
import de.fhhannover.inform.iron.mapserver.messages.ResultItem;
import de.fhhannover.inform.iron.mapserver.messages.SearchResult;
import de.fhhannover.inform.iron.mapserver.messages.SearchResultType;
import de.fhhannover.inform.iron.mapserver.utils.NullCheck;

/**
 * A simple subclass of {@link SearchResult}.
 * 
 * <b>This class does not overwrite the {@link #getByteCount()} method!</b>
 * 
 * @version 0.1
 * @author aw
 * 
 */
class SearchResultImpl extends SearchResult {

	/**
	 * Represents the ordered list of {@link ResultItem} objects.
	 */
	protected List<ResultItem> mResultItems;
	
	/**
	 * Represents the last {@link MetadataContainer} instance used.
	 */
	protected ResultItem mLastResultItem;
	
	SearchResultImpl(String name, SearchResultType type) {
		super(name, type);

		mResultItems = new ArrayList<ResultItem>();
		mLastResultItem = null;
	}

	/**
	 * Constructs a {@link SearchResult} object with a name.
	 */
	SearchResultImpl(String name) {
		this(name, SearchResultType.SEARCH);
	}
	
	/**
	 * Constructs a {@link SearchResult} object without a name.
	 */
	SearchResultImpl() {
		this(null);
	}
	
	/* (non-Javadoc)
	 * @see de.fhhannover.inform.iron.mapserver.messages.SearchResult#addMetadata(de.fhhannover.inform.iron.mapserver.datamodel.graph.MetadataContainer, de.fhhannover.inform.iron.mapserver.datamodel.graph.meta.Metadata)
	 */
	@Override
	public void addMetadata(MetadataContainer mc, Metadata m) {
		
		NullCheck.check(mc, "addMetadata() with no MetadataContainer");
	
		// If mc is not the same as used in the last ResultItem, we have
		// to put a new one in the list.
		if (mLastResultItem == null || !mc.equals(mLastResultItem.getContainer())) {
			mLastResultItem = new ResultItem(mc.copy());
			mResultItems.add(mLastResultItem);
		}
		
		if (m != null)
			mLastResultItem.addMetadata(m.copy());
	}
	
	/* (non-Javadoc)
	 * @see de.fhhannover.inform.iron.mapserver.messages.SearchResult#addMetadataContainer(de.fhhannover.inform.iron.mapserver.datamodel.graph.MetadataContainer)
	 */
	@Override
	public void addMetadataContainer(MetadataContainer mc) {
		NullCheck.check(mc, "mc is null");
		addMetadata(mc, (Metadata)null);
	}

	/* (non-Javadoc)
	 * @see de.fhhannover.inform.iron.mapserver.messages.SearchResult#getResultItems()
	 */
	@Override
	public List<ResultItem> getResultItems() {
		return Collections.unmodifiableList(mResultItems);
	}
}
