/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.datamodel
 * File:    SearchResultReferenceImpl.java
 *
 * Copyright (C) 2010-2011 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.datamodel;

import de.fhhannover.inform.iron.mapserver.datamodel.graph.MetadataContainer;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.meta.Metadata;
import de.fhhannover.inform.iron.mapserver.messages.ResultItem;
import de.fhhannover.inform.iron.mapserver.messages.SearchResult;

/**
 * {@link SearchResult} implementation which does not copy the added containers
 * and metadata objects.
 * 
 * As a result, a {@link SearchResult} created with this implementation will
 * contain references to objects in the real graph for by-reference comparison.
 * <br/><b>Be aware!</b>
 * 
 * @version 0.1
 * @author aw, vp
 */
class SearchResultReferenceImpl extends SearchResultImpl {

public SearchResultReferenceImpl(String name) {
		super(name);
	}
	
	SearchResultReferenceImpl() {
		this(null);
	}
	
	/* (non-Javadoc)
	 * @see de.fhhannover.inform.iron.mapserver.messages.SearchResult#addMetadata(de.fhhannover.inform.iron.mapserver.datamodel.graph.MetadataContainer, de.fhhannover.inform.iron.mapserver.datamodel.graph.meta.Metadata)
	 */
	public void addMetadata(MetadataContainer mc, Metadata m) {
		
		if (mc == null)
			throw new RuntimeException("addMetadata() with no MetadataContainer");
	
		// If mc is not the same as used in the last ResultItem, we have
		// to put a new one in the list.
		if (mLastResultItem == null || !mc.equals(mLastResultItem.getContainer())) {
			mLastResultItem = new ResultItem(mc);
			mResultItems.add(mLastResultItem);
		}
		
		if (m != null)
			mLastResultItem.addMetadata(m);
	}
}

