/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.datamodel.graph
 * File:    Link.java
 *
 * Copyright (C) 2010-2011 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.datamodel.graph;

import de.fhhannover.inform.iron.mapserver.utils.NullCheck;

/**
 * This class represents a link in the MAP graph. It simply consists of
 * two {@link Identifier} objects.
 * 
 * @author aw, vp
 * @version 0.1
 */
public class Link extends MetadataContainer {
 
	private final Identifier ident1;
	private final Identifier ident2;
	
	public Link(Identifier ident1, Identifier ident2){
		NullCheck.check(ident1, "ident1 is null");
		NullCheck.check(ident2, "ident2 is null");
		this.ident1 = ident1;
		this.ident2 = ident2;
		setByteCount(ident1.getByteCount() + ident2.getByteCount());
	}
	
	public Identifier getOtherIdent(Identifier ident) {
		if (this.ident1.equals(ident)){
			return this.ident2;
		} else {
			return this.ident1;
		}
	}
	
	public Identifier getIdent1(){
		return this.ident1;
	}
	
	public Identifier getIdent2(){
		return this.ident2;
	}
	
	@Override
	public boolean equals(Object o) {
		if (o == null)
			return false;
		
		if (this == o)
			return true;

		if (!(o instanceof Link))
			return false;
		
		Link otherLink = (Link)o;
		return (getIdent1().equals(otherLink.getIdent1())
				&& getIdent2().equals(otherLink.getIdent2()))
				|| (getIdent1().equals(otherLink.getIdent2())
				&& getIdent2().equals(otherLink.getIdent1()));
	}

	/* (non-Javadoc)
	 * @see de.fhhannover.inform.iron.mapserver.datamodel.graph.MetadataContainer#toString()
	 */
	@Override
	public String buildToStringString() {
		return "link{" + ident1 + ", " + ident2 + "}";
	}

	/* (non-Javadoc)
	 * @see de.fhhannover.inform.iron.mapserver.datamodel.graph.MetadataContainer#copy()
	 */
	@Override
	public MetadataContainer copy() {
		return new Link(ident1.copy(), ident2.copy());
	}

	@Override
	public int hashCode() {
		return ident1.hashCode() + ident2.hashCode();
	}
}
 
