/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.utils
 * File:    LinkedMap.java
 *
 * Copyright (C) 2010-2011 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.utils;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.List;


/**
 * LinkedMap 
 * 
 * @author vp
 * @version 0.1
 * created: 01.12.09
 * changes:
 *  09.02.10 aw - values() returns a Collection<E>
 */
public class LinkedMap<E> {
	private HashMap<Integer,List<E>> mListMap = new HashMap<Integer, List<E>>();

	/**
	 * Return the LinkedList with elements for the key.
	 * @param key
	 * @return
	 */
	private List<E> get(int key) {
		List<E> list = mListMap.get(key);
		return list;
	}

	/**
	 * If the map contained a mapping for the key, the new value is
	 * added to old.
	 * @param key
	 * @param element
	 */
	public void put(E element) {
		List<E> list = mListMap.get(element.hashCode());
		if (list == null) {
			list = new ArrayList<E>();
			mListMap.put(element.hashCode(), list);
		}
		
		if (list.contains(element))
			throw new RuntimeException("Don't put the same twice, please");
		
		list.add(element);
	}

	/**
	 * Removed element from list for specified key.
	 * @param key
	 * @param element
	 */
	public boolean remove(E element) {
		NullCheck.check(element, "element is null");
		List<E> list = get(element.hashCode());

		if (list != null)
			return list.remove(element);
		
		return false;
	}

	/**
	 * Removed all elements for specified key from this map
	 * if present.
	 * @param key
	 */
	public void removeAll(int key) {
		mListMap.remove(key);
	}

	/**
	 * Return reference to the element in the map.
	 * @param key
	 * @param element
	 * @return
	 */
	public E getElement(int key, E element) {
		NullCheck.check(element, "element is null");
		
		List<E> list= mListMap.get(key);
		
		if (list != null)
			for (E tempElem : list)
				if(tempElem.equals(element))
					return tempElem;
		
		return null;
	}
	
	public Collection<E> values() {
		Collection<E> ret = new ArrayList<E>();
		
		for (List<E> l : mListMap.values())
			for (E e : l)
				ret.add(e);
		
		return ret;
	}
	
	public int size(){
		return mListMap.size();
	}

	public boolean contains(E element) {
		NullCheck.check(element, "element is null");
		return getElement(element.hashCode(), element) != null;
	}
}
